@@ -89,9 +89,15 @@ class Artifact:
 
         # data에 str가 들어오면 file 인지, dir 인지 reference url(http:// or s3:// ..) 인지 체크
         if isinstance(data, str):
-            if os.path.isfile(data):
+            if not os.path.isfile(data):
+                # dir인경우 하위 파일을 순회하며 위의 과정 반복
+                dir_path = data
+                for file_dir_name in os.listdir(dir_path):
+                    file_dir_path = os.path.join(dir_path, file_dir_name)
+                    self.add(file_dir_path, name)
+            else:
                 # file인경우 ArtifactEntry 생성후 local_path, path,size, digest등을 설정한 후 Artifact의 entry_list에 추가
-                local_path = data
+                local_path = os.path.join(".", os.path.relpath(data)) # Convert any path to a relative path
                 if name:
                     # add시 name이 지정된 경우: name/하위폴더명/파일명
                     i_name_begin = local_path.find(name)
@@ -103,12 +109,6 @@ class Artifact:
                 with open(local_path,"rb") as f:
                     digest = hashlib.md5(f.read()).hexdigest()
                 self.entry_list.append(ArtifactEntry(path, local_path, size, digest))
-            else:
-                # dir인경우 하위 파일을 순회하며 위의 과정 반복
-                dir_path = data
-                for file_dir_name in os.listdir(dir_path):
-                    file_dir_path = os.path.join(dir_path, file_dir_name)
-                    self.add(file_dir_path, name)
 
     # Artifact의 정보를 전송하고, ArtifactEntry 각각의 파일을 전송한다
     def upload(self, run: Run) -> bool:
